"""pmp-climatologies

mamakeRevision ID: 4ac252ba38ed
Revises: 4fc26a7d2d28, 6bc6ad5fc5e1
Create Date: 2025-04-16 16:06:58.733426

"""

from collections.abc import Iterable, Sequence
from typing import Union

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision: str = "4ac252ba38ed"
down_revision: Union[str | Iterable[str], None] = ("4fc26a7d2d28", "6bc6ad5fc5e1")
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "pmp_climatology_dataset",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("activity_id", sa.String(), nullable=False),
        sa.Column("frequency", sa.String(), nullable=False),
        sa.Column("grid", sa.String(), nullable=False),
        sa.Column("grid_label", sa.String(), nullable=False),
        sa.Column("institution_id", sa.String(), nullable=False),
        sa.Column("long_name", sa.String(), nullable=False),
        sa.Column("nominal_resolution", sa.String(), nullable=False),
        sa.Column("realm", sa.String(), nullable=False),
        sa.Column("product", sa.String(), nullable=False),
        sa.Column("source_id", sa.String(), nullable=False),
        sa.Column("source_type", sa.String(), nullable=False),
        sa.Column("units", sa.String(), nullable=False),
        sa.Column("variable_id", sa.String(), nullable=False),
        sa.Column("variant_label", sa.String(), nullable=False),
        sa.Column("vertical_levels", sa.Integer(), nullable=False),
        sa.Column("source_version_number", sa.String(), nullable=False),
        sa.Column("instance_id", sa.String(), nullable=False),
        sa.ForeignKeyConstraint(["id"], ["dataset.id"], name=op.f("fk_pmp_climatology_dataset_id_dataset")),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_pmp_climatology_dataset")),
    )
    op.create_table(
        "pmp_climatology_dataset_file",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("dataset_id", sa.Integer(), nullable=False),
        sa.Column("end_time", sa.DateTime(), nullable=True),
        sa.Column("start_time", sa.DateTime(), nullable=True),
        sa.Column("path", sa.String(), nullable=False),
        sa.ForeignKeyConstraint(
            ["dataset_id"],
            ["pmp_climatology_dataset.id"],
            name=op.f("fk_pmp_climatology_dataset_file_dataset_id_pmp_climatology_dataset"),
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_pmp_climatology_dataset_file")),
    )
    with op.batch_alter_table("dataset", schema=None) as batch_op:
        batch_op.alter_column(
            "dataset_type",
            existing_type=sa.VARCHAR(length=8),
            type_=sa.Enum("CMIP6", "CMIP7", "obs4MIPs", "PMPClimatology", name="sourcedatasettype"),
            existing_nullable=False,
        )

    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table("dataset", schema=None) as batch_op:
        batch_op.alter_column(
            "dataset_type",
            existing_type=sa.Enum("CMIP6", "CMIP7", "obs4MIPs", "PMPClimatology", name="sourcedatasettype"),
            type_=sa.VARCHAR(length=8),
            existing_nullable=False,
        )

    op.drop_table("pmp_climatology_dataset_file")
    op.drop_table("pmp_climatology_dataset")
